Module: AppProfiler
- Defined in:
- lib/app_profiler/server.rb,
lib/app_profiler.rb,
lib/app_profiler/profile.rb,
lib/app_profiler/railtie.rb,
lib/app_profiler/version.rb,
lib/app_profiler/profiler.rb,
lib/app_profiler/middleware.rb,
lib/app_profiler/parameters.rb,
lib/app_profiler/yarn/command.rb,
lib/app_profiler/request_parameters.rb,
lib/app_profiler/viewer/base_viewer.rb,
lib/app_profiler/storage/base_storage.rb,
lib/app_profiler/storage/file_storage.rb,
lib/app_profiler/yarn/with_speedscope.rb,
lib/app_profiler/middleware/base_action.rb,
lib/app_profiler/middleware/view_action.rb,
lib/app_profiler/middleware/upload_action.rb,
lib/app_profiler/viewer/speedscope_viewer.rb,
lib/app_profiler/storage/google_cloud_storage.rb,
lib/app_profiler/viewer/speedscope_remote_viewer.rb,
lib/app_profiler/viewer/speedscope_remote_viewer/middleware.rb,
lib/app_profiler/viewer/speedscope_remote_viewer/base_middleware.rb
Overview
This module provides a means to start a golang-inspired profile server it is implemented using stdlib and Rack to avoid additional dependencies
Defined Under Namespace
Modules: Server, Storage, Viewer, Yarn
Classes: ConfigurationError, Middleware, Parameters, Profile, Railtie, RequestParameters
Constant Summary
collapse
- DefaultProfileFormatter =
proc do |upload|
"#{AppProfiler.speedscope_host}#profileURL=#{upload.url}"
end
- VERSION =
"0.1.5"
Class Method Summary
collapse
Class Method Details
78
79
80
|
# File 'lib/app_profiler.rb', line 78
def
||= .dup << "-Data"
end
|
68
69
70
71
72
|
# File 'lib/app_profiler.rb', line 68
def ()
=
= nil
= nil
end
|
.profile_url(upload) ⇒ Object
86
87
88
89
90
|
# File 'lib/app_profiler.rb', line 86
def profile_url(upload)
return unless AppProfiler.profile_url_formatter
AppProfiler.profile_url_formatter.call(upload)
end
|
82
83
84
|
# File 'lib/app_profiler.rb', line 82
def profile_url_formatter=(block)
@@profile_url_formatter = block
end
|
74
75
76
|
# File 'lib/app_profiler.rb', line 74
def
||= .upcase.tr("-", "_").prepend("HTTP_")
end
|
.run(*args, &block) ⇒ Object
55
56
57
|
# File 'lib/app_profiler.rb', line 55
def run(*args, &block)
Profiler.run(*args, &block)
end
|
.start(*args) ⇒ Object
59
60
61
|
# File 'lib/app_profiler.rb', line 59
def start(*args)
Profiler.start(*args)
end
|
.stop ⇒ Object
63
64
65
66
|
# File 'lib/app_profiler.rb', line 63
def stop
Profiler.stop
Profiler.results
end
|